==> thx_role-0.1.9.tar.gz: thx_role-0.1.9/thx/role/api/version1/views.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import get_language_from_request
from rest_framework import viewsets
from thx.api.mixins import ThuxModelMixin

from thx.role.core.views import ThuxRoleViewSetMixin

from ... import models
from . import serializers


# ROLE
class RoleViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.Role.objects.all()
    serializer_class = serializers.RoleSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)


# USER ROLE
class UserRoleViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.UserRole.objects.all()
    serializer_class = serializers.UserRoleSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)


# REQUIRED FIELD
class RequiredFieldViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.RequiredField.objects.all()
    serializer_class = serializers.RequiredFieldSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)


# STATUS FLOW
class StatusFlowViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.StatusFlow.objects.all()
    serializer_class = serializers.StatusFlowSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)


# USED FIELD
class UsedFieldViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.UsedField.objects.all()
    serializer_class = serializers.UsedFieldSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)


# FILTER
class FilterViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.Filter.objects.all()
    serializer_class = serializers.FilterSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)


# MENU
class MenuViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.Menu.objects.all()
    serializer_class = serializers.MenuSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile', None)
        lang = get_language_from_request(self.request)
        self.queryset = models.Menu.get_user_menu(user, lang, profile)
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)

==> thx_role-0.2.0.tar.gz: thx_role-0.2.0/thx/role/api/version1/views.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import get_language_from_request
from rest_framework import viewsets
from thx.api.mixins import ThuxModelMixin

from thx.role.core.views import ThuxRoleViewSetMixin

from ... import models
from . import serializers


# PROFILE
class ProfileViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.Profile.objects.all()
    serializer_class = serializers.ProfileSerializer


# ROLE
class RoleViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.Role.objects.all()
    serializer_class = serializers.RoleSerializer


# REQUIRED FIELD
class RequiredFieldViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.RequiredField.objects.all()
    serializer_class = serializers.RequiredFieldSerializer


# STATUS FLOW
class StatusFlowViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.StatusFlow.objects.all()
    serializer_class = serializers.StatusFlowSerializer


# USED FIELD
class UsedFieldViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.UsedField.objects.all()
    serializer_class = serializers.UsedFieldSerializer


# FILTER
class FilterViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.Filter.objects.all()
    serializer_class = serializers.FilterSerializer


# MENU
class MenuViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    queryset = models.Menu.objects.all()
    serializer_class = serializers.MenuSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile', None)
        lang = get_language_from_request(self.request)
        self.queryset = models.Menu.get_user_menu(user, lang, profile)
        return super().get_queryset()
